@@ -49,6 +49,10 @@ static <- function(x, coef = FALSE, test = TRUE, verbose = FALSE){
   
   lc <- as.list(x$call)  
 
+  if ("list" %in% names(lc)){
+    stop("static does not work with the 'list' argument in seas")
+  }
+
   lc$regression.variables <- x$model$regression$variables
   lc$arima.model <- x$model$arima$model
 
